@@ -29,7 +29,7 @@ RSpec.describe "bundle install with gem sources" do
       expect(bundled_app_lock).to exist
     end
 
-    it "does not create ./.bundle by default", bundler: "< 3" do
+    it "does not create ./.bundle by default" do
       gemfile <<-G
         source "https://gem.repo1"
         gem "myrack"
@@ -49,7 +49,7 @@ RSpec.describe "bundle install with gem sources" do
       expect(bundled_app(".bundle")).not_to exist
     end
 
-    it "creates lock files based on the Gemfile name" do
+    it "creates lockfiles based on the Gemfile name" do
       gemfile bundled_app("OmgFile"), <<-G
         source "https://gem.repo1"
         gem "myrack", "1.0"
@@ -260,7 +260,7 @@ RSpec.describe "bundle install with gem sources" do
         gem "myrack"
       G
 
-      expect(last_command.stdboth).to include(plugin_msg)
+      expect(stdboth).to include(plugin_msg)
     end
 
     describe "with a gem that installs multiple platforms" do
@@ -334,14 +334,14 @@ RSpec.describe "bundle install with gem sources" do
         expect(the_bundle).to include_gems "myrack 1.0"
       end
 
-      it "allows running bundle install --system without deleting foo", bundler: "< 3" do
+      it "allows running bundle install --system without deleting foo" do
         bundle "install --path vendor"
         bundle "install --system"
         FileUtils.rm_r(bundled_app("vendor"))
         expect(the_bundle).to include_gems "myrack 1.0"
       end
 
-      it "allows running bundle install --system after deleting foo", bundler: "< 3" do
+      it "allows running bundle install --system after deleting foo" do
         bundle "install --path vendor"
         FileUtils.rm_r(bundled_app("vendor"))
         bundle "install --system"
@@ -349,7 +349,7 @@ RSpec.describe "bundle install with gem sources" do
       end
     end
 
-    it "finds gems in multiple sources", bundler: "< 3" do
+    it "finds gems in multiple sources" do
       build_repo2 do
         build_gem "myrack", "1.2" do |s|
           s.executables = "myrackup"
@@ -474,7 +474,7 @@ RSpec.describe "bundle install with gem sources" do
       expect(the_bundle).to include_gems("my-private-gem 1.0")
     end
 
-    it "throws a warning if a gem is added once in Gemfile and also inside a gemspec as a development dependency, with different requirements" do
+    it "does not warn if a gem is added once in Gemfile and also inside a gemspec as a development dependency, with compatible requirements" do
       build_lib "my-gem", path: bundled_app do |s|
         s.add_development_dependency "rubocop", "~> 1.36.0"
       end
@@ -494,14 +494,32 @@ RSpec.describe "bundle install with gem sources" do
 
       bundle :install
 
-      expect(err).to include("A gemspec development dependency (rubocop, ~> 1.36.0) is being overridden by a Gemfile dependency (rubocop, >= 0).")
-      expect(err).to include("This behaviour may change in the future. Please remove either of them, or make sure they both have the same requirement")
+      expect(err).to be_empty
 
-      # This is not the best behavior I believe, it would be better if both
-      # requirements are considered if they are compatible, and a version
-      # satisfying both is chosen. But not sure about changing it right now, so
-      # I went with a warning for the time being.
-      expect(the_bundle).to include_gems("rubocop 1.37.1")
+      expect(the_bundle).to include_gems("rubocop 1.36.0")
+    end
+
+    it "raises an error if a gem is added once in Gemfile and also inside a gemspec as a development dependency, with incompatible requirements" do
+      build_lib "my-gem", path: bundled_app do |s|
+        s.add_development_dependency "rubocop", "~> 1.36.0"
+      end
+
+      build_repo4 do
+        build_gem "rubocop", "1.36.0"
+        build_gem "rubocop", "1.37.1"
+      end
+
+      gemfile <<~G
+        source "https://gem.repo4"
+
+        gemspec
+
+        gem "rubocop", "~> 1.37.0", group: :development
+      G
+
+      bundle :install, raise_on_error: false
+
+      expect(err).to include("The rubocop dependency has conflicting requirements in Gemfile (~> 1.37.0) and gemspec (~> 1.36.0)")
     end
 
     it "includes the gem without warning if two gemspecs add it with the same requirement" do
@@ -590,35 +608,6 @@ RSpec.describe "bundle install with gem sources" do
       expect(err).to include("Two gemspec development dependencies have conflicting requirements on the same gem: rubocop (~> 1.36.0) and rubocop (~> 2.0). Bundler cannot continue.")
     end
 
-    it "warns when a Gemfile dependency is overriding a gemspec development dependency, with different requirements" do
-      build_lib "my-gem", path: bundled_app do |s|
-        s.add_development_dependency "rails", ">= 5"
-      end
-
-      build_repo4 do
-        build_gem "rails", "7.0.8"
-      end
-
-      gemfile <<~G
-        source "https://gem.repo4"
-
-        gem "rails", "~> 7.0.8"
-
-        gemspec
-      G
-
-      bundle :install
-
-      expect(err).to include("A gemspec development dependency (rails, >= 5) is being overridden by a Gemfile dependency (rails, ~> 7.0.8).")
-      expect(err).to include("This behaviour may change in the future. Please remove either of them, or make sure they both have the same requirement")
-
-      # This is not the best behavior I believe, it would be better if both
-      # requirements are considered if they are compatible, and a version
-      # satisfying both is chosen. But not sure about changing it right now, so
-      # I went with a warning for the time being.
-      expect(the_bundle).to include_gems("rails 7.0.8")
-    end
-
     it "does not warn if a gem is added once in Gemfile and also inside a gemspec as a development dependency, with same requirements, and different sources" do
       build_lib "my-gem", path: bundled_app do |s|
         s.add_development_dependency "activesupport"
@@ -701,8 +690,6 @@ RSpec.describe "bundle install with gem sources" do
     end
 
     it "gracefully handles error when rubygems server is unavailable" do
-      skip "networking issue" if Gem.win_platform?
-
       install_gemfile <<-G, artifice: nil, raise_on_error: false
         source "https://gem.repo1"
         source "http://0.0.0.0:9384" do
@@ -710,7 +697,7 @@ RSpec.describe "bundle install with gem sources" do
         end
       G
 
-      expect(err).to include("Could not fetch specs from http://0.0.0.0:9384/")
+      expect(err).to eq("Could not reach host 0.0.0.0:9384. Check your network connection and try again.")
       expect(err).not_to include("file://")
     end
 
@@ -733,7 +720,7 @@ RSpec.describe "bundle install with gem sources" do
         gem "ajp-rails", "0.0.0"
       G
 
-      expect(last_command.stdboth).not_to match(/Error Report/i)
+      expect(stdboth).not_to match(/Error Report/i)
       expect(err).to include("An error occurred while installing ajp-rails (0.0.0), and Bundler cannot continue.").
         and include("Bundler::APIResponseInvalidDependenciesError")
     end
@@ -1368,7 +1355,7 @@ RSpec.describe "bundle install with gem sources" do
     it "adds the current platform to the lockfile" do
       bundle "install --verbose"
 
-      expect(out).to include("re-resolving dependencies because your lockfile does not include the current platform")
+      expect(out).to include("re-resolving dependencies because your lockfile is missing the current platform")
       expect(out).not_to include("you are adding a new platform to your lockfile")
 
       expect(lockfile).to eq <<~L
@@ -1511,6 +1498,55 @@ RSpec.describe "bundle install with gem sources" do
     end
   end
 
+  context "when lockfile has incorrect dependencies" do
+    before do
+      build_repo2
+
+      gemfile <<-G
+        source "https://gem.repo2"
+        gem "myrack_middleware"
+      G
+
+      system_gems "myrack_middleware-1.0", path: default_bundle_path
+
+      # we want to raise when the 1.0 line should be followed by "            myrack (= 0.9.1)" but isn't
+      lockfile <<-L
+        GEM
+          remote: https://gem.repo2/
+          specs:
+            myrack_middleware (1.0)
+
+        PLATFORMS
+          #{lockfile_platforms}
+
+        DEPENDENCIES
+          myrack_middleware
+
+        BUNDLED WITH
+          #{Bundler::VERSION}
+      L
+    end
+
+    it "raises a clear error message when frozen" do
+      bundle "config set frozen true"
+      bundle "install", raise_on_error: false
+
+      expect(exitstatus).to eq(41)
+      expect(err).to eq("Bundler found incorrect dependencies in the lockfile for myrack_middleware-1.0")
+    end
+
+    it "updates the lockfile when not frozen" do
+      missing_dep = "myrack (0.9.1)"
+      expect(lockfile).not_to include(missing_dep)
+
+      bundle "config set frozen false"
+      bundle :install
+
+      expect(lockfile).to include(missing_dep)
+      expect(out).to include("now installed")
+    end
+  end
+
   context "with --local flag" do
     before do
       system_gems "myrack-1.0.0", path: default_bundle_path
