@@ -4,7 +4,7 @@ RSpec.describe "bundle platform" do
   context "without flags" do
     it "returns all the output" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
 
         #{ruby_version_correct}
 
@@ -27,7 +27,7 @@ G
 
     it "returns all the output including the patchlevel" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
 
         #{ruby_version_correct_patchlevel}
 
@@ -50,7 +50,7 @@ G
 
     it "doesn't print ruby version requirement if it isn't specified" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
 
         gem "foo"
       G
@@ -68,7 +68,7 @@ G
 
     it "doesn't match the ruby version requirement" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
 
         #{ruby_version_incorrect}
 
@@ -93,7 +93,7 @@ G
   context "--ruby" do
     it "returns ruby version when explicit" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.9.3", :engine => 'ruby', :engine_version => '1.9.3'
 
         gem "foo"
@@ -106,7 +106,7 @@ G
 
     it "defaults to MRI" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.9.3"
 
         gem "foo"
@@ -119,7 +119,7 @@ G
 
     it "handles jruby" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.8.7", :engine => 'jruby', :engine_version => '1.6.5'
 
         gem "foo"
@@ -132,7 +132,7 @@ G
 
     it "handles rbx" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.8.7", :engine => 'rbx', :engine_version => '1.2.4'
 
         gem "foo"
@@ -145,7 +145,7 @@ G
 
     it "handles truffleruby" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "2.5.1", :engine => 'truffleruby', :engine_version => '1.0.0-rc6'
 
         gem "foo"
@@ -158,46 +158,46 @@ G
 
     it "raises an error if engine is used but engine version is not" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.8.7", :engine => 'rbx'
 
         gem "foo"
       G
 
-      bundle "platform", :raise_on_error => false
+      bundle "platform", raise_on_error: false
 
       expect(exitstatus).not_to eq(0)
     end
 
     it "raises an error if engine_version is used but engine is not" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.8.7", :engine_version => '1.2.4'
 
         gem "foo"
       G
 
-      bundle "platform", :raise_on_error => false
+      bundle "platform", raise_on_error: false
 
       expect(exitstatus).not_to eq(0)
     end
 
     it "raises an error if engine version doesn't match ruby version for MRI" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "1.8.7", :engine => 'ruby', :engine_version => '1.2.4'
 
         gem "foo"
       G
 
-      bundle "platform", :raise_on_error => false
+      bundle "platform", raise_on_error: false
 
       expect(exitstatus).not_to eq(0)
     end
 
     it "should print if no ruby version is specified" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
 
         gem "foo"
       G
@@ -209,13 +209,13 @@ G
 
     it "handles when there is a locked requirement" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby "< 1.8.7"
       G
 
       lockfile <<-L
         GEM
-          remote: #{file_uri_for(gem_repo1)}/
+          remote: https://gem.repo1/
           specs:
 
         PLATFORMS
@@ -236,12 +236,12 @@ G
 
     it "handles when there is a lockfile with no requirement" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
       G
 
       lockfile <<-L
         GEM
-          remote: #{file_uri_for(gem_repo1)}/
+          remote: https://gem.repo1/
           specs:
 
         PLATFORMS
@@ -259,7 +259,7 @@ G
 
     it "handles when there is a requirement in the gemfile" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby ">= 1.8.7"
       G
 
@@ -269,7 +269,7 @@ G
 
     it "handles when there are multiple requirements in the gemfile" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         ruby ">= 1.8.7", "< 2.0.0"
       G
 
@@ -315,8 +315,8 @@ G
   context "bundle install" do
     it "installs fine when the ruby version matches" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_correct}
       G
@@ -326,8 +326,8 @@ G
 
     it "installs fine with any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_correct_engineless}
       G
@@ -337,8 +337,8 @@ G
 
     it "installs fine when the patchlevel matches" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_correct_patchlevel}
       G
@@ -347,9 +347,9 @@ G
     end
 
     it "doesn't install when the ruby version doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_incorrect}
       G
@@ -359,9 +359,9 @@ G
     end
 
     it "doesn't install when engine doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{engine_incorrect}
       G
@@ -371,9 +371,9 @@ G
     end
 
     it "doesn't install when engine version doesn't match", :jruby_only do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{engine_version_incorrect}
       G
@@ -383,9 +383,9 @@ G
     end
 
     it "doesn't install when patchlevel doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
@@ -398,13 +398,13 @@ G
   context "bundle check" do
     it "checks fine when the ruby version matches" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_correct}
       G
@@ -415,13 +415,13 @@ G
 
     it "checks fine with any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_correct_engineless}
       G
@@ -432,69 +432,69 @@ G
 
     it "fails when ruby version doesn't match" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{ruby_version_incorrect}
       G
 
-      bundle :check, :raise_on_error => false
+      bundle :check, raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails when engine doesn't match" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{engine_incorrect}
       G
 
-      bundle :check, :raise_on_error => false
+      bundle :check, raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails when engine version doesn't match", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{engine_version_incorrect}
       G
 
-      bundle :check, :raise_on_error => false
+      bundle :check, raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
 
-      bundle :check, :raise_on_error => false
+      bundle :check, raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -504,57 +504,57 @@ G
       build_repo2
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
       G
     end
 
     it "updates successfully when the ruby version matches" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
 
         #{ruby_version_correct}
       G
       update_repo2 do
-        build_gem "rack", "1.2" do |s|
-          s.executables = "rackup"
+        build_gem "myrack", "1.2" do |s|
+          s.executables = "myrackup"
         end
 
         build_gem "activesupport", "3.0"
       end
 
-      bundle "update", :all => true
-      expect(the_bundle).to include_gems "rack 1.2", "rack-obama 1.0", "activesupport 3.0"
+      bundle "update", all: true
+      expect(the_bundle).to include_gems "myrack 1.2", "myrack-obama 1.0", "activesupport 3.0"
     end
 
     it "updates fine with any engine", :jruby_only do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
 
         #{ruby_version_correct_engineless}
       G
       update_repo2 do
-        build_gem "rack", "1.2" do |s|
-          s.executables = "rackup"
+        build_gem "myrack", "1.2" do |s|
+          s.executables = "myrackup"
         end
 
         build_gem "activesupport", "3.0"
       end
 
-      bundle "update", :all => true
-      expect(the_bundle).to include_gems "rack 1.2", "rack-obama 1.0", "activesupport 3.0"
+      bundle "update", all: true
+      expect(the_bundle).to include_gems "myrack 1.2", "myrack-obama 1.0", "activesupport 3.0"
     end
 
     it "fails when ruby version doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
 
         #{ruby_version_incorrect}
       G
@@ -562,15 +562,15 @@ G
         build_gem "activesupport", "3.0"
       end
 
-      bundle :update, :all => true, :raise_on_error => false
+      bundle :update, all: true, raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails when ruby engine doesn't match", :jruby_only do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
 
         #{engine_incorrect}
       G
@@ -578,15 +578,15 @@ G
         build_gem "activesupport", "3.0"
       end
 
-      bundle :update, :all => true, :raise_on_error => false
+      bundle :update, all: true, raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails when ruby engine version doesn't match", :jruby_only do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport"
-        gem "rack-obama"
+        gem "myrack-obama"
 
         #{engine_version_incorrect}
       G
@@ -594,14 +594,14 @@ G
         build_gem "activesupport", "3.0"
       end
 
-      bundle :update, :all => true, :raise_on_error => false
+      bundle :update, all: true, raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
@@ -609,7 +609,7 @@ G
         build_gem "activesupport", "3.0"
       end
 
-      bundle :update, :all => true, :raise_on_error => false
+      bundle :update, all: true, raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -617,14 +617,14 @@ G
   context "bundle info" do
     before do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
       G
     end
 
     it "prints path if ruby version is correct" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         #{ruby_version_correct}
@@ -636,7 +636,7 @@ G
 
     it "prints path if ruby version is correct for any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         #{ruby_version_correct_engineless}
@@ -646,46 +646,46 @@ G
       expect(out).to eq(default_bundle_path("gems", "rails-2.3.2").to_s)
     end
 
-    it "fails if ruby version doesn't match", :bundler => "< 3" do
+    it "fails if ruby version doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         #{ruby_version_incorrect}
       G
 
-      bundle "show rails", :raise_on_error => false
+      bundle "show rails", raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
-    it "fails if engine doesn't match", :bundler => "< 3" do
+    it "fails if engine doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         #{engine_incorrect}
       G
 
-      bundle "show rails", :raise_on_error => false
+      bundle "show rails", raise_on_error: false
       should_be_engine_incorrect
     end
 
-    it "fails if engine version doesn't match", :bundler => "< 3", :jruby_only => true do
+    it "fails if engine version doesn't match", jruby_only: true do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         #{engine_version_incorrect}
       G
 
-      bundle "show rails", :raise_on_error => false
+      bundle "show rails", raise_on_error: false
       should_be_engine_version_incorrect
     end
 
-    it "fails when patchlevel doesn't match", :bundler => "< 3" do
+    it "fails when patchlevel doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
@@ -693,7 +693,7 @@ G
         build_gem "activesupport", "3.0"
       end
 
-      bundle "show rails", :raise_on_error => false
+      bundle "show rails", raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -701,80 +701,80 @@ G
   context "bundle cache" do
     before do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
       G
     end
 
     it "copies the .gem file to vendor/cache when ruby version matches" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_correct}
       G
 
       bundle :cache
-      expect(bundled_app("vendor/cache/rack-1.0.0.gem")).to exist
+      expect(bundled_app("vendor/cache/myrack-1.0.0.gem")).to exist
     end
 
     it "copies the .gem file to vendor/cache when ruby version matches for any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_correct_engineless}
       G
 
       bundle :cache
-      expect(bundled_app("vendor/cache/rack-1.0.0.gem")).to exist
+      expect(bundled_app("vendor/cache/myrack-1.0.0.gem")).to exist
     end
 
     it "fails if the ruby version doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails if the engine doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{engine_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails if the engine version doesn't match", :jruby_only do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{engine_version_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -782,80 +782,80 @@ G
   context "bundle pack" do
     before do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
       G
     end
 
     it "copies the .gem file to vendor/cache when ruby version matches" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_correct}
       G
 
       bundle :cache
-      expect(bundled_app("vendor/cache/rack-1.0.0.gem")).to exist
+      expect(bundled_app("vendor/cache/myrack-1.0.0.gem")).to exist
     end
 
     it "copies the .gem file to vendor/cache when ruby version matches any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_correct_engineless}
       G
 
       bundle :cache
-      expect(bundled_app("vendor/cache/rack-1.0.0.gem")).to exist
+      expect(bundled_app("vendor/cache/myrack-1.0.0.gem")).to exist
     end
 
     it "fails if the ruby version doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{ruby_version_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails if the engine doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{engine_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails if the engine version doesn't match", :jruby_only do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack'
+        source "https://gem.repo1"
+        gem 'myrack'
 
         #{engine_version_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
 
-      bundle :cache, :raise_on_error => false
+      bundle :cache, raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -863,179 +863,142 @@ G
   context "bundle exec" do
     before do
       ENV["BUNDLER_FORCE_TTY"] = "true"
-      system_gems "rack-1.0.0", "rack-0.9.1", :path => default_bundle_path
+      system_gems "myrack-1.0.0", "myrack-0.9.1", path: default_bundle_path
     end
 
     it "activates the correct gem when ruby version matches" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack", "0.9.1"
+        source "https://gem.repo1"
+        gem "myrack", "0.9.1"
 
         #{ruby_version_correct}
       G
 
-      bundle "exec rackup"
+      bundle "exec myrackup"
       expect(out).to include("0.9.1")
     end
 
     it "activates the correct gem when ruby version matches any engine", :jruby_only do
-      system_gems "rack-1.0.0", "rack-0.9.1", :path => default_bundle_path
+      system_gems "myrack-1.0.0", "myrack-0.9.1", path: default_bundle_path
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack", "0.9.1"
+        source "https://gem.repo1"
+        gem "myrack", "0.9.1"
 
         #{ruby_version_correct_engineless}
       G
 
-      bundle "exec rackup"
+      bundle "exec myrackup"
       expect(out).to include("0.9.1")
     end
 
     it "fails when the ruby version doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack", "0.9.1"
+        source "https://gem.repo1"
+        gem "myrack", "0.9.1"
 
         #{ruby_version_incorrect}
       G
 
-      bundle "exec rackup", :raise_on_error => false
+      bundle "exec myrackup", raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails when the engine doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack", "0.9.1"
+        source "https://gem.repo1"
+        gem "myrack", "0.9.1"
 
         #{engine_incorrect}
       G
 
-      bundle "exec rackup", :raise_on_error => false
+      bundle "exec myrackup", raise_on_error: false
       should_be_engine_incorrect
     end
 
-    # it "fails when the engine version doesn't match", :jruby_only do
-    #   gemfile <<-G
-    #     gem "rack", "0.9.1"
-    #
-    #     #{engine_version_incorrect}
-    #   G
-    #
-    #   bundle "exec rackup"
-    #   should_be_engine_version_incorrect
-    # end
+    it "fails when the engine version doesn't match", :jruby_only do
+      gemfile <<-G
+        gem "myrack", "0.9.1"
+
+        #{engine_version_incorrect}
+      G
+
+      bundle "exec myrackup", raise_on_error: false
+      should_be_engine_version_incorrect
+    end
 
     it "fails when patchlevel doesn't match" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
 
-      bundle "exec rackup", :raise_on_error => false
+      bundle "exec myrackup", raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
 
-  context "bundle console", :bundler => "< 3" do
+  context "bundle console" do
     before do
+      build_repo2 do
+        build_dummy_irb
+      end
+
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo2"
+        gem "irb"
+        gem "myrack"
         gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
+        gem "myrack_middleware", :group => :development
       G
     end
 
     it "starts IRB with the default group loaded when ruby version matches", :readline do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
-
-        #{ruby_version_correct}
-      G
+      gemfile gemfile + "\n\n#{ruby_version_correct}\n"
 
       bundle "console" do |input, _, _|
-        input.puts("puts RACK")
+        input.puts("puts MYRACK")
         input.puts("exit")
       end
       expect(out).to include("0.9.1")
     end
 
     it "starts IRB with the default group loaded when ruby version matches", :readline, :jruby_only do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
-
-        #{ruby_version_correct_engineless}
-      G
+      gemfile gemfile + "\n\n#{ruby_version_correct_engineless}\n"
 
       bundle "console" do |input, _, _|
-        input.puts("puts RACK")
+        input.puts("puts MYRACK")
         input.puts("exit")
       end
       expect(out).to include("0.9.1")
     end
 
     it "fails when ruby version doesn't match" do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
+      gemfile gemfile + "\n\n#{ruby_version_incorrect}\n"
 
-        #{ruby_version_incorrect}
-      G
-
-      bundle "console", :raise_on_error => false
+      bundle "console", raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails when engine doesn't match" do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
+      gemfile gemfile + "\n\n#{engine_incorrect}\n"
 
-        #{engine_incorrect}
-      G
-
-      bundle "console", :raise_on_error => false
+      bundle "console", raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails when engine version doesn't match", :jruby_only do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
+      gemfile gemfile + "\n\n#{engine_version_incorrect}\n"
 
-        #{engine_version_incorrect}
-      G
-
-      bundle "console", :raise_on_error => false
+      bundle "console", raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
-      gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
-        gem "activesupport", :group => :test
-        gem "rack_middleware", :group => :development
+      gemfile gemfile + "\n\n#{patchlevel_incorrect}\n"
 
-        #{patchlevel_incorrect}
-      G
-
-      bundle "console", :raise_on_error => false
+      bundle "console", raise_on_error: false
       should_be_patchlevel_incorrect
     end
   end
@@ -1043,9 +1006,9 @@ G
   context "Bundler.setup" do
     before do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack", :group => :test
+        gem "myrack", :group => :test
       G
 
       ENV["BUNDLER_FORCE_TTY"] = "true"
@@ -1053,9 +1016,9 @@ G
 
     it "makes a Gemfile.lock if setup succeeds" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{ruby_version_correct}
       G
@@ -1068,9 +1031,9 @@ G
 
     it "makes a Gemfile.lock if setup succeeds for any engine", :jruby_only do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{ruby_version_correct_engineless}
       G
@@ -1082,68 +1045,68 @@ G
     end
 
     it "fails when ruby version doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{ruby_version_incorrect}
       G
 
       FileUtils.rm(bundled_app_lock)
 
-      ruby "require 'bundler/setup'", :env => { "BUNDLER_VERSION" => Bundler::VERSION }, :raise_on_error => false
+      ruby "require 'bundler/setup'", env: { "BUNDLER_VERSION" => Bundler::VERSION }, raise_on_error: false
 
       expect(bundled_app_lock).not_to exist
       should_be_ruby_version_incorrect
     end
 
     it "fails when engine doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{engine_incorrect}
       G
 
       FileUtils.rm(bundled_app_lock)
 
-      ruby "require 'bundler/setup'", :env => { "BUNDLER_VERSION" => Bundler::VERSION }, :raise_on_error => false
+      ruby "require 'bundler/setup'", env: { "BUNDLER_VERSION" => Bundler::VERSION }, raise_on_error: false
 
       expect(bundled_app_lock).not_to exist
       should_be_engine_incorrect
     end
 
     it "fails when engine version doesn't match", :jruby_only do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{engine_version_incorrect}
       G
 
       FileUtils.rm(bundled_app_lock)
 
-      ruby "require 'bundler/setup'", :env => { "BUNDLER_VERSION" => Bundler::VERSION }, :raise_on_error => false
+      ruby "require 'bundler/setup'", env: { "BUNDLER_VERSION" => Bundler::VERSION }, raise_on_error: false
 
       expect(bundled_app_lock).not_to exist
       should_be_engine_version_incorrect
     end
 
     it "fails when patchlevel doesn't match" do
-      install_gemfile <<-G, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, raise_on_error: false
+        source "https://gem.repo1"
         gem "yard"
-        gem "rack"
+        gem "myrack"
 
         #{patchlevel_incorrect}
       G
 
       FileUtils.rm(bundled_app_lock)
 
-      ruby "require 'bundler/setup'", :env => { "BUNDLER_VERSION" => Bundler::VERSION }, :raise_on_error => false
+      ruby "require 'bundler/setup'", env: { "BUNDLER_VERSION" => Bundler::VERSION }, raise_on_error: false
 
       expect(bundled_app_lock).not_to exist
       should_be_patchlevel_incorrect
@@ -1153,11 +1116,11 @@ G
   context "bundle outdated" do
     before do
       build_repo2 do
-        build_git "foo", :path => lib_path("foo")
+        build_git "foo", path: lib_path("foo")
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
       G
@@ -1166,18 +1129,18 @@ G
     it "returns list of outdated gems when the ruby version matches" do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{ruby_version_correct}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
 
       expected_output = <<~TABLE.gsub("x", "\\\h").tr(".", "\.").strip
         Gem            Current      Latest       Requested  Groups
@@ -1192,18 +1155,18 @@ G
       bundle :install
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{ruby_version_correct_engineless}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
 
       expected_output = <<~TABLE.gsub("x", "\\\h").tr(".", "\.").strip
         Gem            Current      Latest       Requested  Groups
@@ -1217,90 +1180,90 @@ G
     it "fails when the ruby version doesn't match" do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{ruby_version_incorrect}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
       should_be_ruby_version_incorrect
     end
 
     it "fails when the engine doesn't match" do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{engine_incorrect}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
       should_be_engine_incorrect
     end
 
     it "fails when the engine version doesn't match", :jruby_only do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{engine_version_incorrect}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
       should_be_engine_version_incorrect
     end
 
     it "fails when the patchlevel doesn't match", :jruby_only do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{patchlevel_incorrect}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
       should_be_patchlevel_incorrect
     end
 
     it "fails when the patchlevel is a fixnum", :jruby_only do
       update_repo2 do
         build_gem "activesupport", "3.0"
-        update_git "foo", :path => lib_path("foo")
+        update_git "foo", path: lib_path("foo")
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo2)}"
+        source "https://gem.repo2"
         gem "activesupport", "2.3.5"
         gem "foo", :git => "#{lib_path("foo")}"
 
         #{patchlevel_fixnum}
       G
 
-      bundle "outdated", :raise_on_error => false
+      bundle "outdated", raise_on_error: false
       should_be_patchlevel_fixnum
     end
   end
