@@ -40,16 +40,14 @@ RSpec.describe "The library itself" do
     "#{filename} has spaces on the EOL on lines #{failing_lines.join(", ")}"
   end
 
-  def check_for_straneous_quotes(filename)
-    return if File.expand_path(filename) == __FILE__
-
+  def check_for_extraneous_quotes(filename)
     failing_lines = []
     each_line(filename) do |line, number|
-      failing_lines << number + 1 if /’/.match?(line)
+      failing_lines << number + 1 if /\u{2019}/.match?(line)
     end
 
     return if failing_lines.empty?
-    "#{filename} has an straneous quote on lines #{failing_lines.join(", ")}"
+    "#{filename} has an extraneous quote on lines #{failing_lines.join(", ")}"
   end
 
   def check_for_expendable_words(filename)
@@ -96,12 +94,12 @@ RSpec.describe "The library itself" do
     expect(error_messages.compact).to be_well_formed
   end
 
-  it "has no estraneous quotes" do
+  it "has no extraneous quotes" do
     exempt = /vendor|vcr_cassettes|LICENSE|rbreadline\.diff/
     error_messages = []
     tracked_files.each do |filename|
       next if filename&.match?(exempt)
-      error_messages << check_for_straneous_quotes(filename)
+      error_messages << check_for_extraneous_quotes(filename)
     end
     expect(error_messages.compact).to be_well_formed
   end
@@ -146,6 +144,7 @@ RSpec.describe "The library itself" do
       gem.coc
       gem.linter
       gem.mit
+      gem.bundle
       gem.rubocop
       gem.test
       git.allow_insecure
@@ -167,7 +166,8 @@ RSpec.describe "The library itself" do
         line.scan(/Bundler\.settings\[:#{key_pattern}\]/).flatten.each {|s| all_settings[s] << "referenced at `#{filename}:#{number.succ}`" }
       end
     end
-    documented_settings = File.read("lib/bundler/man/bundle-config.1.ronn")[/LIST OF AVAILABLE KEYS.*/m].scan(/^\* `#{key_pattern}`/).flatten
+    settings_section = File.read("lib/bundler/man/bundle-config.1.ronn").split(/^## /).find {|section| section.start_with?("LIST OF AVAILABLE KEYS") }
+    documented_settings = settings_section.scan(/^\* `#{key_pattern}`/).flatten
 
     documented_settings.each do |s|
       all_settings.delete(s)
@@ -193,9 +193,10 @@ RSpec.describe "The library itself" do
   end
 
   it "ships the correct set of files" do
-    git_list = git_ls_files(ruby_core? ? "lib/bundler lib/bundler.rb libexec/bundle*" : "lib exe CHANGELOG.md LICENSE.md README.md bundler.gemspec")
+    git_list = tracked_files.reject {|f| f.start_with?("spec/") }
 
     gem_list = loaded_gemspec.files
+    gem_list.map! {|f| f.sub(%r{\Aexe/}, "libexec/") } if ruby_core?
 
     expect(git_list).to match_array(gem_list)
   end
@@ -217,7 +218,7 @@ RSpec.describe "The library itself" do
       end
     end
 
-    warnings = last_command.stdboth.split("\n")
+    warnings = stdboth.split("\n")
     # ignore warnings around deprecated Object#=~ method in RubyGems
     warnings.reject! {|w| w =~ %r{rubygems\/version.rb.*deprecated\ Object#=~} }
 
@@ -237,9 +238,24 @@ RSpec.describe "The library itself" do
     expect(all_bad_requires).to be_empty, "#{all_bad_requires.size} internal requires that should use `require_relative`: #{all_bad_requires}"
   end
 
+  # We don't want our artifice code to activate bundler, but it needs to use the
+  # namespaced implementation of `Net::HTTP`. So we duplicate the file in
+  # bundler that loads that.
+  it "keeps vendored_net_http spec code in sync with the lib implementation" do
+    lib_implementation_path = File.join(source_lib_dir, "bundler", "vendored_net_http.rb")
+    expect(File.exist?(lib_implementation_path)).to be_truthy
+    lib_code = File.read(lib_implementation_path)
+
+    spec_implementation_path = File.join(spec_dir, "support", "vendored_net_http.rb")
+    expect(File.exist?(spec_implementation_path)).to be_truthy
+    spec_code = File.read(spec_implementation_path)
+
+    expect(lib_code).to eq(spec_code)
+  end
+
   private
 
   def each_line(filename, &block)
-    File.readlines(filename, :encoding => "UTF-8").each_with_index(&block)
+    File.readlines(filename, encoding: "UTF-8").each_with_index(&block)
   end
 end
