@@ -16,8 +16,6 @@ class TestGemCommandsInstallCommand < Gem::TestCase
     @cmd.options[:document] = []
 
     @gemdeps = "tmp_install_gemdeps"
-
-    common_installer_setup
   end
 
   def teardown
@@ -44,7 +42,7 @@ class TestGemCommandsInstallCommand < Gem::TestCase
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_explicit_version_includes_prerelease
@@ -66,7 +64,7 @@ class TestGemCommandsInstallCommand < Gem::TestCase
       end
     end
 
-    assert_equal %w[a-2.a], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2.a], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_local
@@ -92,7 +90,7 @@ class TestGemCommandsInstallCommand < Gem::TestCase
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
   end
@@ -183,40 +181,35 @@ ERROR:  Could not find a valid gem 'bar' (= 0.5) (required by 'foo' (>= 0)) in a
       end
     end
 
-    assert_equal %w[a-2 b-2.a c-3], @cmd.installed_specs.map {|spec| spec.full_name }.sort
+    assert_equal %w[a-2 b-2.a c-3], @cmd.installed_specs.map(&:full_name).sort
 
     assert_match "3 gems installed", @ui.output
   end
 
   def test_execute_no_user_install
-    pend "skipped on MS Windows (chmod has no effect)" if win_platform?
+    pend "skipped on MS Windows (chmod has no effect)" if Gem.win_platform?
     pend "skipped in root privilege" if Process.uid.zero?
 
-    specs = spec_fetcher do |fetcher|
-      fetcher.gem "a", 2
+    spec_fetcher do |fetcher|
+      fetcher.download "a", 2
     end
 
     @cmd.options[:user_install] = false
 
-    FileUtils.mv specs["a-2"].cache_file, @tempdir
-
     @cmd.options[:args] = %w[a]
 
     use_ui @ui do
-      orig_dir = Dir.pwd
-      begin
-        FileUtils.chmod 0o755, @userhome
-        FileUtils.chmod 0o555, @gemhome
+      FileUtils.chmod 0o755, @userhome
+      FileUtils.chmod 0o555, @gemhome
 
-        Dir.chdir @tempdir
-        assert_raise Gem::FilePermissionError do
-          @cmd.execute
-        end
-      ensure
-        Dir.chdir orig_dir
-        FileUtils.chmod 0o755, @gemhome
+      assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
+        @cmd.execute
       end
+    ensure
+      FileUtils.chmod 0o755, @gemhome
     end
+
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name).sort
   end
 
   def test_execute_local_missing
@@ -436,21 +429,6 @@ ERROR:  Possible alternatives: non_existent_with_hint
     assert_equal expected, output
   end
 
-  def test_execute_conflicting_install_options
-    @cmd.options[:user_install] = true
-    @cmd.options[:install_dir] = "whatever"
-
-    use_ui @ui do
-      assert_raise Gem::MockGemUi::TermError do
-        @cmd.execute
-      end
-    end
-
-    expected = "ERROR:  Use --install-dir or --user-install but not both\n"
-
-    assert_equal expected, @ui.error
-  end
-
   def test_execute_prerelease_skipped_when_no_flag_set
     spec_fetcher do |fetcher|
       fetcher.gem "a", 1
@@ -466,7 +444,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_prerelease_wins_over_previous_ver
@@ -484,7 +462,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2.a], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2.a], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_with_version_specified_by_colon
@@ -501,7 +479,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_prerelease_skipped_when_non_pre_available
@@ -519,7 +497,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_required_ruby_version
@@ -549,7 +527,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_required_ruby_version_upper_bound
@@ -570,7 +548,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2.0], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2.0], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_required_ruby_version_specific_not_met
@@ -608,7 +586,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1.0], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1.0], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_required_ruby_version_specific_prerelease_not_met
@@ -669,17 +647,10 @@ ERROR:  Possible alternatives: non_existent_with_hint
     @cmd.options[:args] = %w[a]
 
     use_ui @ui do
-      # Don't use Dir.chdir with a block, it warnings a lot because
-      # of a downstream Dir.chdir with a block
-      old = Dir.getwd
-
-      begin
-        Dir.chdir @tempdir
+      Dir.chdir @tempdir do
         assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
           @cmd.execute
         end
-      ensure
-        Dir.chdir old
       end
     end
 
@@ -687,7 +658,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
 
     assert_path_exist File.join(a2.doc_dir, "ri")
     assert_path_exist File.join(a2.doc_dir, "rdoc")
-  end
+  end if defined?(Gem::RDoc) && !Gem.rdoc_hooks_defined_via_plugin?
 
   def test_execute_rdoc_with_path
     specs = spec_fetcher do |fetcher|
@@ -706,24 +677,17 @@ ERROR:  Possible alternatives: non_existent_with_hint
     @cmd.options[:args] = %w[a]
 
     use_ui @ui do
-      # Don't use Dir.chdir with a block, it warnings a lot because
-      # of a downstream Dir.chdir with a block
-      old = Dir.getwd
-
-      begin
-        Dir.chdir @tempdir
+      Dir.chdir @tempdir do
         assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
           @cmd.execute
         end
-      ensure
-        Dir.chdir old
       end
     end
 
     wait_for_child_process_to_exit
 
     assert_path_exist "whatever/doc/a-2", "documentation not installed"
-  end
+  end if defined?(Gem::RDoc) && !Gem.rdoc_hooks_defined_via_plugin?
 
   def test_execute_saves_build_args
     specs = spec_fetcher do |fetcher|
@@ -742,17 +706,10 @@ ERROR:  Possible alternatives: non_existent_with_hint
     @cmd.options[:args] = %w[a]
 
     use_ui @ui do
-      # Don't use Dir.chdir with a block, it warnings a lot because
-      # of a downstream Dir.chdir with a block
-      old = Dir.getwd
-
-      begin
-        Dir.chdir @tempdir
+      Dir.chdir @tempdir do
         assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
           @cmd.execute
         end
-      ensure
-        Dir.chdir old
       end
     end
 
@@ -775,7 +732,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
   end
@@ -795,7 +752,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
   end
@@ -815,7 +772,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1], @cmd.installed_specs.map(&:full_name)
     assert_match "1 gem installed", @ui.output
 
     a1_gemspec = File.join(@gemhome, "specifications", "a-1.gemspec")
@@ -869,7 +826,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
 
@@ -903,7 +860,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2 b-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2 b-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "2 gems installed", @ui.output
   end
@@ -945,7 +902,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-1 b-1], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-1 b-1], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_execute_conservative
@@ -971,7 +928,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[b-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[b-2], @cmd.installed_specs.map(&:full_name)
 
     assert_equal "", @ui.error
     assert_match "1 gem installed", @ui.output
@@ -993,7 +950,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
 
     @cmd.install_gem "a", ">= 0"
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|s| s.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert done_installing, "documentation was not generated"
   end
@@ -1007,7 +964,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
 
     @cmd.install_gem "a", ">= 0"
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_install_gem_ignore_dependencies_remote_platform_local
@@ -1024,7 +981,39 @@ ERROR:  Possible alternatives: non_existent_with_hint
 
     @cmd.install_gem "a", ">= 0"
 
-    assert_equal %W[a-3-#{local}], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %W[a-3-#{local}], @cmd.installed_specs.map(&:full_name)
+  end
+
+  def test_install_gem_platform_specificity_match
+    util_set_arch "arm64-darwin-20"
+
+    spec_fetcher do |fetcher|
+      %w[ruby universal-darwin universal-darwin-20 x64-darwin-20 arm64-darwin-20].each do |platform|
+        fetcher.download "a", 3 do |s|
+          s.platform = platform
+        end
+      end
+    end
+
+    @cmd.install_gem "a", ">= 0"
+
+    assert_equal %w[a-3-arm64-darwin-20], @cmd.installed_specs.map(&:full_name)
+  end
+
+  def test_install_gem_platform_specificity_match_reverse_order
+    util_set_arch "arm64-darwin-20"
+
+    spec_fetcher do |fetcher|
+      %w[ruby universal-darwin universal-darwin-20 x64-darwin-20 arm64-darwin-20].reverse_each do |platform|
+        fetcher.download "a", 3 do |s|
+          s.platform = platform
+        end
+      end
+    end
+
+    @cmd.install_gem "a", ">= 0"
+
+    assert_equal %w[a-3-arm64-darwin-20], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_install_gem_ignore_dependencies_specific_file
@@ -1038,7 +1027,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
 
     @cmd.install_gem File.join(@tempdir, spec.file_name), nil
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|s| s.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
   end
 
   def test_parses_requirement_from_gemname
@@ -1067,7 +1056,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
     end
 
     assert_equal 2, e.exit_code
-    assert_match %r{Could not find a valid gem 'a' \(= 10.0\)}, @ui.error
+    assert_match(/Could not find a valid gem 'a' \(= 10.0\)/, @ui.error)
   end
 
   def test_show_errors_on_failure
@@ -1108,7 +1097,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
 
@@ -1133,7 +1122,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "1 gem installed", @ui.output
 
@@ -1160,7 +1149,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[], @cmd.installed_specs.map(&:full_name)
 
     assert_match "Using a (2)", @ui.output
     assert File.exist?("#{@gemdeps}.lock")
@@ -1184,7 +1173,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[], @cmd.installed_specs.map(&:full_name)
 
     assert_match "Using a (2)", @ui.output
     assert !File.exist?("#{@gemdeps}.lock")
@@ -1209,7 +1198,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[], @cmd.installed_specs.map(&:full_name)
 
     assert_match "Using a (1)", @ui.output
   end
@@ -1231,11 +1220,35 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    assert_equal %w[a-2], @cmd.installed_specs.map {|spec| spec.full_name }
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
 
     assert_match "Installing a (2)", @ui.output
   end
 
+  def test_execute_installs_from_a_gemdeps_with_prerelease
+    spec_fetcher do |fetcher|
+      fetcher.download "a", 1
+      fetcher.download "a", "2.a"
+    end
+
+    File.open @gemdeps, "w" do |f|
+      f << "gem 'a'"
+    end
+
+    @cmd.handle_options %w[--prerelease]
+    @cmd.options[:gemdeps] = @gemdeps
+
+    use_ui @ui do
+      assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
+        @cmd.execute
+      end
+    end
+
+    assert_equal %w[a-2.a], @cmd.installed_specs.map(&:full_name)
+
+    assert_match "Installing a (2.a)", @ui.output
+  end
+
   def test_execute_installs_deps_a_gemdeps
     spec_fetcher do |fetcher|
       fetcher.download "q", "1.0"
@@ -1254,7 +1267,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    names = @cmd.installed_specs.map {|spec| spec.full_name }
+    names = @cmd.installed_specs.map(&:full_name)
 
     assert_equal %w[q-1.0 r-2.0], names
 
@@ -1281,7 +1294,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    names = @cmd.installed_specs.map {|spec| spec.full_name }
+    names = @cmd.installed_specs.map(&:full_name)
 
     assert_equal %w[r-2.0], names
 
@@ -1308,7 +1321,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    names = @cmd.installed_specs.map {|spec| spec.full_name }
+    names = @cmd.installed_specs.map(&:full_name)
 
     assert_equal %w[q-1.0 r-2.0], names
 
@@ -1340,7 +1353,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    names = @cmd.installed_specs.map {|spec| spec.full_name }
+    names = @cmd.installed_specs.map(&:full_name)
 
     assert_equal %w[q-1.0 r-2.0], names
 
@@ -1357,7 +1370,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       fetcher.gem "r", "2.0", "q" => nil
     end
 
-    i = Gem::Installer.at specs["q-1.0"].cache_file, :install_dir => "gf-path"
+    i = Gem::Installer.at specs["q-1.0"].cache_file, install_dir: "gf-path"
     i.install
 
     assert File.file?("gf-path/specifications/q-1.0.gemspec"), "not installed"
@@ -1375,7 +1388,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       end
     end
 
-    names = @cmd.installed_specs.map {|spec| spec.full_name }
+    names = @cmd.installed_specs.map(&:full_name)
 
     assert_equal %w[r-2.0], names
 
@@ -1554,7 +1567,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
   end
 
   def test_suggest_update_if_enabled
-    TestUpdateSuggestion.with_eglible_environment(cmd: @cmd) do
+    TestUpdateSuggestion.with_eligible_environment(cmd: @cmd) do
       spec_fetcher do |fetcher|
         fetcher.gem "a", 2
       end
@@ -1570,4 +1583,31 @@ ERROR:  Possible alternatives: non_existent_with_hint
       assert_includes @ui.output, "A new release of RubyGems is available: 1.2.3 → 2.0.0!"
     end
   end
+
+  def test_execute_bindir_with_nonexistent_parent_dirs
+    spec_fetcher do |fetcher|
+      fetcher.gem "a", 2 do |s|
+        s.executables = %w[a_bin]
+        s.files = %w[bin/a_bin]
+      end
+    end
+
+    @cmd.options[:args] = %w[a]
+
+    nested_bin_dir = File.join(@tempdir, "not", "exists")
+    refute_directory_exists nested_bin_dir, "Nested bin directory should not exist yet"
+
+    @cmd.options[:bin_dir] = nested_bin_dir
+
+    use_ui @ui do
+      assert_raise Gem::MockGemUi::SystemExitException, @ui.error do
+        @cmd.execute
+      end
+    end
+
+    assert_directory_exists nested_bin_dir, "Nested bin directory should exist now"
+    assert_path_exist File.join(nested_bin_dir, "a_bin")
+
+    assert_equal %w[a-2], @cmd.installed_specs.map(&:full_name)
+  end
 end
