@@ -2,13 +2,17 @@
 
 source "https://rubygems.org"
 
-gem "rack", "~> 3.0"
-gem "rackup", "~> 2.1"
-gem "webrick", "~> 1.9"
+gem "rack", "~> 3.1"
 gem "rack-test", "~> 2.1"
 gem "compact_index", "~> 0.15.0"
 gem "sinatra", "~> 4.1"
 gem "rake", "~> 13.1"
 gem "builder", "~> 3.2"
 gem "rb_sys"
+gem "fiddle"
 gem "rubygems-generate_index", "~> 1.1"
+gem "ruby-graphviz"
+gem "psych"
+gem "etc", platforms: [:ruby, :windows]
+gem "open3"
+gem "shellwords"
